@@ -92,6 +92,15 @@ class Bay(base.APIBase):
     docker_volume_size = wtypes.IntegerType(minimum=1)
     """The size in GB of the docker volume"""
 
+    labels = wtypes.DictType(str, str)
+    """One or more key/value pairs"""
+
+    master_flavor_id = wtypes.StringType(min_length=1, max_length=255)
+    """The master flavor of this Bay"""
+
+    flavor_id = wtypes.StringType(min_length=1, max_length=255)
+    """The flavor of this Bay"""
+
     bay_create_timeout = wsme.wsattr(wtypes.IntegerType(minimum=0), default=60)
     """Timeout for creating the bay in minutes. Default to 60 if not set"""
 
@@ -174,7 +183,8 @@ class Bay(base.APIBase):
     def _convert_with_links(bay, url, expand=True):
         if not expand:
             bay.unset_fields_except(['uuid', 'name', 'baymodel_id',
-                                     'docker_volume_size',
+                                     'docker_volume_size', 'labels',
+                                     'master_flavor_id', 'flavor_id',
                                      'node_count', 'status',
                                      'bay_create_timeout', 'master_count',
                                      'stack_id'])
@@ -199,6 +209,9 @@ class Bay(base.APIBase):
                      node_count=2,
                      master_count=1,
                      docker_volume_size=1,
+                     labels={},
+                     master_flavor_id=None,
+                     flavor_id=None,
                      bay_create_timeout=15,
                      stack_id='49dc23f5-ffc9-40c3-9d34-7be7f9e34d63',
                      status=fields.ClusterStatus.CREATE_COMPLETE,
@@ -424,6 +437,18 @@ class BaysController(base.Controller):
         if bay.docker_volume_size == wtypes.Unset:
             bay.docker_volume_size = baymodel.docker_volume_size
 
+        # If labels is not present, use baymodel value
+        if bay.labels is None:
+            bay.labels = baymodel.labels
+
+        # If master_flavor_id is not present, use baymodel value
+        if bay.master_flavor_id == wtypes.Unset or not bay.master_flavor_id:
+            bay.master_flavor_id = baymodel.master_flavor_id
+
+        # If flavor_id is not present, use baymodel value
+        if bay.flavor_id == wtypes.Unset or not bay.flavor_id:
+            bay.flavor_id = baymodel.flavor_id
+
         bay_dict = bay.as_dict()
         bay_dict['keypair'] = baymodel.keypair_id
         attr_validator.validate_os_resources(context, baymodel.as_dict(),
