@@ -13,23 +13,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
 import pecan
 import wsme
 from wsme import types as wtypes
 
 from magnum.api.controllers import base
 from magnum.api.controllers.v1 import collection
+from magnum.api.controllers.v1 import types
 from magnum.api import expose
 from magnum.api import utils as api_utils
+from magnum.api import validation
 from magnum.common import exception
 from magnum.common import policy
 from magnum.i18n import _
 from magnum import objects
 from magnum.objects import fields
 
-LOG = logging.getLogger(__name__)
-
 
 class Quota(base.APIBase):
     """API representation of a project Quota.
@@ -118,7 +117,8 @@ class QuotaController(base.Controller):
                                        sort_key=sort_key,
                                        sort_dir=sort_dir)
 
-    @expose.expose(QuotaCollection, int, int, wtypes.text, wtypes.text, bool)
+    @expose.expose(QuotaCollection, int, int, wtypes.text, wtypes.text,
+                   types.boolean)
     def get_all(self, marker=None, limit=None, sort_key='id',
                 sort_dir='asc', all_tenants=False):
         """Retrieve a list of quotas.
@@ -162,6 +162,7 @@ class QuotaController(base.Controller):
         return Quota.convert(quota)
 
     @expose.expose(Quota, body=Quota, status_code=201)
+    @validation.enforce_valid_project_id_on_create()
     def post(self, quota):
         """Create Quota.
 
