@@ -116,6 +116,9 @@ class Cluster(Base):
     cluster_template_id = Column(String(255))
     keypair = Column(String(255))
     docker_volume_size = Column(Integer())
+    labels = Column(JSONEncodedDict)
+    master_flavor_id = Column(String(255))
+    flavor_id = Column(String(255))
     stack_id = Column(String(255))
     api_address = Column(String(255))
     node_addresses = Column(JSONEncodedList)
@@ -235,3 +238,21 @@ class Quota(Base):
     project_id = Column(String(255))
     resource = Column(String(255))
     hard_limit = Column(Integer())
+
+
+class Federation(Base):
+    """Represents a Federation."""
+    __tablename__ = 'federation'
+    __table_args__ = (
+        schema.UniqueConstraint("uuid", name="uniq_federation0uuid"),
+        table_args()
+    )
+    id = Column(Integer, primary_key=True)
+    project_id = Column(String(255))
+    uuid = Column(String(36))
+    name = Column(String(255))
+    hostcluster_id = Column(String(255))
+    member_ids = Column(JSONEncodedList)
+    status = Column(String(20))
+    status_reason = Column(Text)
+    properties = Column(JSONEncodedDict)
