@@ -34,7 +34,8 @@ class Driver(object):
     @classmethod
     def load_entry_points(cls):
         for entry_point in iter_entry_points('magnum.drivers'):
-            yield entry_point, entry_point.load(require=False)
+            if entry_point.name not in CONF.drivers.disabled_drivers:
+                yield entry_point, entry_point.load(require=False)
 
     @classmethod
     def get_drivers(cls):
@@ -173,6 +174,21 @@ class Driver(object):
         raise NotImplementedError("Subclasses must implement "
                                   "'delete_cluster'.")
 
+    @abc.abstractmethod
+    def create_federation(self, context, federation):
+        raise NotImplementedError("Subclasses must implement "
+                                  "'create_federation'.")
+
+    @abc.abstractmethod
+    def update_federation(self, context, federation):
+        raise NotImplementedError("Subclasses must implement "
+                                  "'update_federation'.")
+
+    @abc.abstractmethod
+    def delete_federation(self, context, federation):
+        raise NotImplementedError("Subclasses must implement "
+                                  "'delete_federation'.")
+
     def get_monitor(self, context, cluster):
         """return the monitor with container data for this driver."""
 
