@@ -2,6 +2,12 @@
 
 . /etc/sysconfig/heat-params
 
+if [ "$VERIFY_CA" == "True" ]; then
+    VERIFY_CA=""
+else
+    VERIFY_CA="-k"
+fi
+
 WC_NOTIFY_BIN=/usr/local/bin/wc-notify
 WC_NOTIFY_SERVICE=/etc/systemd/system/wc-notify.service
 
@@ -11,7 +17,7 @@ until curl -sf "http://127.0.0.1:8080/healthz"; do
     echo "Waiting for Kubernetes API..."
     sleep 5
 done
-$WAIT_CURL --data-binary '{"status": "SUCCESS"}'
+$WAIT_CURL $VERIFY_CA --data-binary '{"status": "SUCCESS"}'
 EOF
 
 cat > $WC_NOTIFY_SERVICE <<EOF
