@@ -6,14 +6,14 @@ if [ "$NETWORK_DRIVER" != "flannel" ]; then
     exit 0
 fi
 
-. /etc/sysconfig/flanneld
-
 FLANNEL_JSON=/etc/sysconfig/flannel-network.json
 FLANNELD_CONFIG=/etc/sysconfig/flanneld
 
-sed -i '
-    /^FLANNEL_ETCD_ENDPOINTS=/ s/=.*/="http:\/\/127.0.0.1:2379"/
-' /etc/sysconfig/flanneld
+cat > /etc/sysconfig/flanneld <<EOF
+FLANNEL_ETCD_ENDPOINTS="http://127.0.0.1:2379"
+FLANNEL_ETCD_PREFIX="/atomic.io/network"
+FLANNEL_OPTIONS=
+EOF
 
 # Generate a flannel configuration that we will
 # store into etcd using curl.
