@@ -14,6 +14,9 @@ import abc
 import os
 import six
 
+from string import ascii_letters
+from string import digits
+
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import importutils
@@ -71,6 +74,15 @@ class HeatDriver(driver.Driver):
 
         raise NotImplementedError("Must implement 'get_template_definition'")
 
+    def create_federation(self, context, federation):
+        return NotImplementedError("Must implement 'create_federation'")
+
+    def update_federation(self, context, federation):
+        return NotImplementedError("Must implement 'update_federation'")
+
+    def delete_federation(self, context, federation):
+        return NotImplementedError("Must implement 'delete_federation'")
+
     def update_cluster_status(self, context, cluster):
         if cluster.stack_id is None:
             # NOTE(mgoddard): During cluster creation it is possible to poll
@@ -109,8 +121,19 @@ class HeatDriver(driver.Driver):
                                                          env_files)
         tpl_files.update(env_map)
 
+        # Make sure we end up with a valid hostname
+        valid_chars = set(ascii_letters + digits + '-')
+
+        # valid hostnames are 63 chars long, leaving enough room
+        # to add the random id (for uniqueness)
+        stack_name = cluster.name[:30]
+        stack_name = stack_name.replace('_', '-')
+        stack_name = stack_name.replace('.', '-')
+        stack_name = ''.join(filter(valid_chars.__contains__, stack_name))
+
         # Make sure no duplicate stack name
-        stack_name = '%s-%s' % (cluster.name, short_id.generate_id())
+        stack_name = '%s-%s' % (stack_name, short_id.generate_id())
+        stack_name = stack_name.lower()
         if cluster_create_timeout:
             heat_timeout = cluster_create_timeout
         else:
