@@ -48,9 +48,9 @@ class SwarmFedoraTemplateDefinition(template_def.BaseTemplateDefinition):
         self.add_parameter('number_of_nodes',
                            cluster_attr='node_count')
         self.add_parameter('master_flavor',
-                           cluster_template_attr='master_flavor_id')
+                           cluster_attr='master_flavor_id')
         self.add_parameter('node_flavor',
-                           cluster_template_attr='flavor_id')
+                           cluster_attr='flavor_id')
         self.add_parameter('docker_volume_size',
                            cluster_attr='docker_volume_size')
         self.add_parameter('volume_driver',
@@ -102,15 +102,17 @@ class SwarmFedoraTemplateDefinition(template_def.BaseTemplateDefinition):
                       'swarm_strategy']
 
         extra_params['auth_url'] = context.auth_url
+        extra_params['nodes_affinity_policy'] = \
+            CONF.cluster.nodes_affinity_policy
 
         # set docker_volume_type
         # use the configuration default if None provided
-        docker_volume_type = cluster_template.labels.get(
+        docker_volume_type = cluster.labels.get(
             'docker_volume_type', CONF.cinder.default_docker_volume_type)
         extra_params['docker_volume_type'] = docker_volume_type
 
         for label in label_list:
-            extra_params[label] = cluster_template.labels.get(label)
+            extra_params[label] = cluster.labels.get(label)
 
         if cluster_template.registry_enabled:
             extra_params['swift_region'] = CONF.docker_registry.swift_region
