@@ -13,7 +13,6 @@
 # under the License.
 
 from magnum.drivers.common import k8s_monitor
-from magnum.drivers.common.k8s_scale_manager import K8sScaleManager
 from magnum.drivers.heat import driver
 from magnum.drivers.k8s_fedora_ironic_v1 import template_def
 
@@ -35,4 +34,7 @@ class Driver(driver.HeatDriver):
         return k8s_monitor.K8sMonitor(context, cluster)
 
     def get_scale_manager(self, context, osclient, cluster):
-        return K8sScaleManager(context, osclient, cluster)
+        # FIXME: Until the kubernetes client is fixed, remove
+        # the scale_manager.
+        # https://bugs.launchpad.net/magnum/+bug/1746510
+        return None
