@@ -31,9 +31,9 @@ class UbuntuMesosTemplateDefinition(template_def.BaseTemplateDefinition):
         self.add_parameter('number_of_slaves',
                            cluster_attr='node_count')
         self.add_parameter('master_flavor',
-                           cluster_template_attr='master_flavor_id')
+                           cluster_attr='master_flavor_id')
         self.add_parameter('slave_flavor',
-                           cluster_template_attr='flavor_id')
+                           cluster_attr='flavor_id')
         self.add_parameter('cluster_name',
                            cluster_attr='name')
         self.add_parameter('volume_driver',
@@ -58,7 +58,7 @@ class UbuntuMesosTemplateDefinition(template_def.BaseTemplateDefinition):
         osc = self.get_osc(context)
         extra_params['auth_url'] = context.auth_url
         extra_params['username'] = context.user_name
-        extra_params['tenant_name'] = context.tenant
+        extra_params['tenant_name'] = context.project_id
         extra_params['domain_name'] = context.domain_name
         extra_params['region_name'] = osc.cinder_region_name()
 
@@ -68,7 +68,7 @@ class UbuntuMesosTemplateDefinition(template_def.BaseTemplateDefinition):
                       'mesos_slave_executor_env_variables']
 
         for label in label_list:
-            extra_params[label] = cluster_template.labels.get(label)
+            extra_params[label] = cluster.labels.get(label)
 
         scale_mgr = kwargs.pop('scale_manager', None)
         if scale_mgr:
