@@ -27,9 +27,9 @@ PRIVATE_KEY=
 
 echo "If private key is specified, save to temp and use that; else, use default"
 if [[ "$KEYPAIR" == "default" ]]; then
-    PRIVATE_KEY=$(readlink -f ~/.ssh/id_rsa)
+    PRIVATE_KEY=$(readlink -f ~/.ssh/id_rsa_magnum)
 else
-    PRIVATE_KEY="$(mktemp id_rsa.$SSH_IP.XXX)"
+    PRIVATE_KEY="$(mktemp id_rsa_magnum.$SSH_IP.XXX)"
     echo -en "$KEYPAIR" > $PRIVATE_KEY
 fi
 
@@ -56,8 +56,8 @@ if [[ "$COE" == "kubernetes" ]]; then
     remote_exec $SSH_USER "sudo journalctl -u kube-proxy --no-pager" kube-proxy.log
     remote_exec $SSH_USER "sudo journalctl -u etcd --no-pager" etcd.log
     remote_exec $SSH_USER "sudo journalctl -u kube-apiserver --no-pager" kube-apiserver.log
-    remote_exec $SSH_USER "kubectl logs --namespace=kube-system \$(kubectl --namespace=kube-system get pods | grep kube-scheduler | awk '{print \$1}')" kube-scheduler.log
-    remote_exec $SSH_USER "kubectl logs --namespace=kube-system \$(kubectl --namespace=kube-system get pods | grep kube-controller-manager | awk '{print \$1}')" kube-controller-manager.log
+    remote_exec $SSH_USER "sudo journalctl -u kube-scheduler --no-pager" kube-scheduler.log
+    remote_exec $SSH_USER "sudo journalctl -u kube-controller-manager --no-pager" kube-controller-manager.log
     remote_exec $SSH_USER "sudo journalctl -u docker-storage-setup --no-pager" docker-storage-setup.log
     remote_exec $SSH_USER "sudo systemctl status docker-storage-setup -l" docker-storage-setup.service.status.log
     remote_exec $SSH_USER "sudo systemctl show docker-storage-setup --no-pager" docker-storage-setup.service.show.log
@@ -75,8 +75,31 @@ if [[ "$COE" == "kubernetes" ]]; then
     remote_exec $SSH_USER "sudo netstat -an" netstat.log
     remote_exec $SSH_USER "sudo df -h" dfh.log
     remote_exec $SSH_USER "sudo journalctl -u wc-notify --no-pager" wc-notify.log
-    remote_exec $SSH_USER "cat /etc/sysconfig/heat-params" heat-params
-elif [[ "$COE" == "swarm" ]]; then
+    remote_exec $SSH_USER "sudo cat /etc/sysconfig/heat-params" heat-params
+    remote_exec $SSH_USER "sudo cat /etc/etcd/etcd.conf" etcd.conf
+    remote_exec $SSH_USER "sudo cat /etc/kubernetes/config" kubernetes-config
+    remote_exec $SSH_USER "sudo cat /etc/kubernetes/apiserver" kubernetes-apiserver-config
+    remote_exec $SSH_USER "sudo cat /etc/kubernetes/controller-manager" kubernetes-controller-config
+    remote_exec $SSH_USER "sudo cat /etc/kubernetes/kubelet" kubelet-config
+    remote_exec $SSH_USER "sudo cat /etc/kubernetes/proxy" kubernetes-proxy-config
+    remote_exec $SSH_USER "sudo cat /etc/kubernetes/kubeconfig.yaml" kubeconfig.yaml
+    remote_exec $SSH_USER "sudo tail -n +1 -- /etc/kubernetes/manifests/*" kubernetes-manifests
+    remote_exec $SSH_USER "sudo tail -n +1 -- /etc/kubernetes/certs/*" kubernetes-certs
+    remote_exec $SSH_USER "sudo cat /usr/local/bin/wc-notify" bin-wc-notify
+    remote_exec $SSH_USER "sudo cat /etc/kubernetes/kube_openstack_config" kube_openstack_config
+    remote_exec $SSH_USER "sudo cat /etc/sysconfig/flanneld" flanneld.sysconfig
+    remote_exec $SSH_USER "sudo cat /usr/local/bin/flannel-config" bin-flannel-config
+    remote_exec $SSH_USER "sudo cat /etc/sysconfig/flannel-network.json" flannel-network.json.sysconfig
+    remote_exec $SSH_USER "sudo cat /usr/local/bin/flannel-docker-bridge" bin-flannel-docker-bridge
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/docker.service.d/flannel.conf" docker-flannel.conf
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/flanneld.service.d/flannel-docker-bridge.conf" flannel-docker-bridge.conf
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/flannel-docker-bridge.service" flannel-docker-bridge.service
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/flannel-config.service" flannel-config.service
+    remote_exec $SSH_USER "sudo journalctl -u heat-container-agent --no-pager" heat-container-agent.log
+    remote_exec $SSH_USER "sudo journalctl -u kube-enable-monitoring --no-pager" kube-enable-monitoring.service.log
+    remote_exec $SSH_USER "sudo atomic containers list" atomic-containers-list.log
+    remote_exec $SSH_USER "sudo atomic images list" atomic-images-list.log
+elif [[ "$COE" == "swarm" || "$COE" == "swarm-mode" ]]; then
     SSH_USER=fedora
     remote_exec $SSH_USER "sudo systemctl --full list-units --no-pager" systemctl_list_units.log
     remote_exec $SSH_USER "sudo journalctl -u cloud-config --no-pager" cloud-config.log
@@ -87,6 +110,7 @@ elif [[ "$COE" == "swarm" ]]; then
     remote_exec $SSH_USER "sudo journalctl -u etcd --no-pager" etcd.log
     remote_exec $SSH_USER "sudo journalctl -u swarm-manager --no-pager" swarm-manager.log
     remote_exec $SSH_USER "sudo journalctl -u swarm-agent --no-pager" swarm-agent.log
+    remote_exec $SSH_USER "sudo journalctl -u swarm-worker --no-pager" swarm-worker.log
     remote_exec $SSH_USER "sudo journalctl -u docker-storage-setup --no-pager" docker-storage-setup.log
     remote_exec $SSH_USER "sudo systemctl status docker-storage-setup -l" docker-storage-setup.service.status.log
     remote_exec $SSH_USER "sudo systemctl show docker-storage-setup --no-pager" docker-storage-setup.service.show.log
@@ -106,7 +130,22 @@ elif [[ "$COE" == "swarm" ]]; then
     remote_exec $SSH_USER "sudo ip a" ipa.log
     remote_exec $SSH_USER "sudo netstat -an" netstat.log
     remote_exec $SSH_USER "sudo df -h" dfh.log
-    remote_exec $SSH_USER "cat /etc/sysconfig/heat-params" heat-params
+    remote_exec $SSH_USER "sudo cat /etc/sysconfig/heat-params" heat-params
+    remote_exec $SSH_USER "sudo cat /etc/etcd/etcd.conf" etcd.conf
+    remote_exec $SSH_USER "sudo ls -lR /etc/docker" docker-certs
+    remote_exec $SSH_USER "sudo cat /etc/sysconfig/flanneld" flanneld.sysconfig
+    remote_exec $SSH_USER "sudo cat /etc/sysconfig/flannel-network.json" flannel-network.json.sysconfig
+    remote_exec $SSH_USER "sudo cat /usr/local/bin/flannel-docker-bridge" bin-flannel-docker-bridge
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/docker.service.d/flannel.conf" docker-flannel.conf
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/flanneld.service.d/flannel-docker-bridge.conf" flannel-docker-bridge.conf
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/flannel-docker-bridge.service" flannel-docker-bridge.service
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/swarm-manager.service" swarm-manager.service
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/swarm-manager-failure.service" swarm-manager-failure.service
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/swarm-agent.service" swarm-agent.service
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/swarm-agent-failure.service" swarm-agent-failure.service
+    remote_exec $SSH_USER "sudo cat /etc/systemd/system/swarm-worker.service" swarm-worker.service
+    remote_exec $SSH_USER "sudo cat /usr/local/bin/magnum-start-swarm-manager" bin-magnum-start-swarm-manager
+    remote_exec $SSH_USER "sudo cat /usr/local/bin/magnum-start-swarm-worker" bin-magnum-start-swarm-worker
 else
     echo "ERROR: Unknown COE '${COE}'"
     EXIT_CODE=1
