@@ -254,7 +254,9 @@ class TestPatch(api_base.FunctionalTest):
                           [{'path': '/public', 'value': True,
                             'op': 'replace'}])
 
-    def test_update_baymodel_with_bay_allow_update(self):
+    @mock.patch.object(magnum_policy, 'enforce')
+    def test_update_baymodel_with_bay_allow_update(self, mock_policy):
+        mock_policy.return_value = True
         baymodel = obj_utils.create_test_cluster_template(self.context)
         obj_utils.create_test_cluster(self.context,
                                       cluster_template_id=baymodel.uuid)
