@@ -144,6 +144,17 @@ class TestListCluster(api_base.FunctionalTest):
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['errors'])
 
+    @mock.patch("magnum.common.policy.enforce")
+    @mock.patch("magnum.common.context.make_context")
+    def test_get_one_by_uuid_admin(self, mock_context, mock_policy):
+        temp_uuid = uuidutils.generate_uuid()
+        obj_utils.create_test_cluster(self.context, uuid=temp_uuid,
+                                      project_id=temp_uuid)
+        self.context.is_admin = True
+        response = self.get_json(
+            '/clusters/%s' % temp_uuid)
+        self.assertEqual(temp_uuid, response['uuid'])
+
     def test_get_one_by_name_multiple_cluster(self):
         obj_utils.create_test_cluster(self.context, name='test_cluster',
                                       uuid=uuidutils.generate_uuid())
@@ -169,6 +180,19 @@ class TestListCluster(api_base.FunctionalTest):
         self.assertEqual(cluster_list[-1].uuid,
                          response['clusters'][0]['uuid'])
 
+    @mock.patch("magnum.common.policy.enforce")
+    @mock.patch("magnum.common.context.make_context")
+    def test_get_all_with_all_projects(self, mock_context, mock_policy):
+        for id_ in range(4):
+            temp_uuid = uuidutils.generate_uuid()
+            obj_utils.create_test_cluster(self.context, id=id_,
+                                          uuid=temp_uuid,
+                                          project_id=id_)
+
+        self.context.is_admin = True
+        response = self.get_json('/clusters')
+        self.assertEqual(4, len(response['clusters']))
+
     def test_detail(self):
         cluster = obj_utils.create_test_cluster(self.context)
         response = self.get_json('/clusters/detail')
@@ -790,6 +814,15 @@ class TestPost(api_base.FunctionalTest):
         cluster, timeout = self.mock_cluster_create.call_args
         self.assertEqual(3, cluster[0].docker_volume_size)
 
+    def test_create_cluster_with_labels(self):
+        bdict = apiutils.cluster_post_data()
+        bdict['labels'] = {'key': 'value'}
+        response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        cluster, timeout = self.mock_cluster_create.call_args
+        self.assertEqual({'key': 'value'}, cluster[0].labels)
+
     def test_create_cluster_without_docker_volume_size(self):
         bdict = apiutils.cluster_post_data()
         # Remove the default docker_volume_size from the cluster dict.
@@ -801,6 +834,16 @@ class TestPost(api_base.FunctionalTest):
         # Verify docker_volume_size from ClusterTemplate is used
         self.assertEqual(20, cluster[0].docker_volume_size)
 
+    def test_create_cluster_without_labels(self):
+        bdict = apiutils.cluster_post_data()
+        bdict.pop('labels')
+        response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        cluster, timeout = self.mock_cluster_create.call_args
+        # Verify labels from ClusterTemplate is used
+        self.assertEqual({'key1': u'val1', 'key2': u'val2'}, cluster[0].labels)
+
     def test_create_cluster_with_invalid_docker_volume_size(self):
         invalid_values = [(-1, None), ('notanint', None),
                           (1, 'devicemapper'), (2, 'devicemapper')]
@@ -812,6 +855,49 @@ class TestPost(api_base.FunctionalTest):
             self.assertEqual(400, response.status_int)
             self.assertTrue(response.json['errors'])
 
+    def test_create_cluster_with_invalid_labels(self):
+        bdict = apiutils.cluster_post_data(labels='invalid')
+        response = self.post_json('/clusters', bdict, expect_errors=True)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(400, response.status_int)
+        self.assertTrue(response.json['errors'])
+
+    def test_create_cluster_with_master_flavor_id(self):
+        bdict = apiutils.cluster_post_data()
+        bdict['master_flavor_id'] = 'm2.small'
+        response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        cluster, timeout = self.mock_cluster_create.call_args
+        self.assertEqual('m2.small', cluster[0].master_flavor_id)
+
+    def test_create_cluster_without_master_flavor_id(self):
+        bdict = apiutils.cluster_post_data()
+        response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        cluster, timeout = self.mock_cluster_create.call_args
+        # Verify master_flavor_id from ClusterTemplate is used
+        self.assertEqual('m1.small', cluster[0].master_flavor_id)
+
+    def test_create_cluster_with_flavor_id(self):
+        bdict = apiutils.cluster_post_data()
+        bdict['flavor_id'] = 'm2.small'
+        response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        cluster, timeout = self.mock_cluster_create.call_args
+        self.assertEqual('m2.small', cluster[0].flavor_id)
+
+    def test_create_cluster_without_flavor_id(self):
+        bdict = apiutils.cluster_post_data()
+        response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        cluster, timeout = self.mock_cluster_create.call_args
+        # Verify flavor_id from ClusterTemplate is used
+        self.assertEqual('m1.small', cluster[0].flavor_id)
+
 
 class TestDelete(api_base.FunctionalTest):
     def setUp(self):
@@ -864,6 +950,16 @@ class TestDelete(api_base.FunctionalTest):
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['errors'])
 
+    @mock.patch("magnum.common.policy.enforce")
+    @mock.patch("magnum.common.context.make_context")
+    def test_delete_cluster_as_admin(self, mock_context, mock_policy):
+        temp_uuid = uuidutils.generate_uuid()
+        obj_utils.create_test_cluster(self.context, uuid=temp_uuid)
+        self.context.is_admin = True
+        response = self.delete('/clusters/%s' % temp_uuid,
+                               expect_errors=True)
+        self.assertEqual(204, response.status_int)
+
 
 class TestClusterPolicyEnforcement(api_base.FunctionalTest):
     def setUp(self):
