@@ -334,6 +334,19 @@ class TestPatch(api_base.FunctionalTest):
                                  self.cluster_template.uuid)
         self.assertEqual(response['public'], True)
 
+    def test_update_cluster_template_replace_labels_success(self):
+        cluster_template = obj_utils.create_test_cluster_template(self.context)
+        response = self.patch_json('/clustertemplates/%s' %
+                                   cluster_template.uuid,
+                                   [{'path': '/labels',
+                                     'value': '{\'etcd_volume_size\': \'1\'}',
+                                     'op': 'replace'}],
+                                   expect_errors=True)
+        self.assertEqual(200, response.status_int)
+        response = self.get_json('/clustertemplates/%s' %
+                                 self.cluster_template.uuid)
+        self.assertEqual(response['labels'], {'etcd_volume_size': '1'})
+
     def test_update_cluster_template_with_cluster_not_allow_update(self):
         cluster_template = obj_utils.create_test_cluster_template(self.context)
         obj_utils.create_test_cluster(
@@ -1004,6 +1017,14 @@ class TestPost(api_base.FunctionalTest):
             self.assertEqual(201, resp.status_int)
             self.assertIsNotNone(resp.json['name'])
 
+    def test_create_cluster_with_disabled_driver(self):
+        cfg.CONF.set_override('disabled_drivers',
+                              ['mesos_ubuntu_v1'],
+                              group='drivers')
+        bdict = apiutils.cluster_template_post_data(coe="mesos")
+        self.assertRaises(AppError, self.post_json, '/clustertemplates',
+                          bdict)
+
 
 class TestDelete(api_base.FunctionalTest):
 
@@ -1064,6 +1085,17 @@ class TestDelete(api_base.FunctionalTest):
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['errors'])
 
+    @mock.patch("magnum.common.policy.enforce")
+    @mock.patch("magnum.common.context.make_context")
+    def test_delete_cluster_template_as_admin(self, mock_context, mock_policy):
+        temp_uuid = uuidutils.generate_uuid()
+        obj_utils.create_test_cluster_template(self.context, uuid=temp_uuid,
+                                               project_id=temp_uuid)
+        self.context.is_admin = True
+        response = self.delete('/clustertemplates/%s' % temp_uuid,
+                               expect_errors=True)
+        self.assertEqual(204, response.status_int)
+
 
 class TestClusterTemplatePolicyEnforcement(api_base.FunctionalTest):
 
