@@ -39,6 +39,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'network_driver': 'network_driver',
             'volume_driver': 'volume_driver',
             'docker_volume_size': 20,
+            'master_flavor_id': 'flavor_id',
             'docker_storage_driver': 'devicemapper',
             'cluster_distro': 'fedora-atomic',
             'coe': 'kubernetes',
@@ -55,8 +56,10 @@ class TestClusterConductorWithK8s(base.TestCase):
                        'prometheus_monitoring': 'False',
                        'grafana_admin_passwd': 'fake_pwd',
                        'kube_dashboard_enabled': 'True',
+                       'influx_grafana_dashboard_enabled': 'True',
                        'docker_volume_type': 'lvmdriver-1',
-                       'etcd_volume_size': '0'},
+                       'etcd_volume_size': 0,
+                       'availability_zone': 'az_1'},
             'tls_disabled': False,
             'server_type': 'vm',
             'registry_enabled': False,
@@ -76,6 +79,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'master_count': 1,
             'discovery_url': 'https://discovery.etcd.io/test',
             'docker_volume_size': 20,
+            'flavor_id': 'flavor_id',
             'master_addresses': ['172.17.2.18'],
             'ca_cert_ref': 'http://barbican/v1/containers/xx-xx-xx-xx',
             'magnum_cert_ref': 'http://barbican/v1/containers/xx-xx-xx-xx',
@@ -84,9 +88,31 @@ class TestClusterConductorWithK8s(base.TestCase):
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
             'trust_id': 'bd11efc5-d4e2-4dac-bbce-25e348ddf7de',
             'coe_version': 'fake-version',
+            'labels': {'flannel_network_cidr': '10.101.0.0/16',
+                       'flannel_network_subnetlen': '26',
+                       'flannel_backend': 'vxlan',
+                       'system_pods_initial_delay': '15',
+                       'system_pods_timeout': '1',
+                       'admission_control_list': 'fake_list',
+                       'prometheus_monitoring': 'False',
+                       'grafana_admin_passwd': 'fake_pwd',
+                       'kube_dashboard_enabled': 'True',
+                       'docker_volume_type': 'lvmdriver-1',
+                       'availability_zone': 'az_1',
+                       'cert_manager_api': 'False',
+                       'ingress_controller': 'i-controller',
+                       'ingress_controller_role': 'i-controller-role',
+                       'kubelet_options': '--kubelet',
+                       'kubeapi_options': '--kubeapi',
+                       'kubecontroller_options': '--kubecontroller',
+                       'kubescheduler_options': '--kubescheduler',
+                       'kubeproxy_options': '--kubeproxy',
+                       'influx_grafana_dashboard_enabled': 'True'},
+            'master_flavor_id': 'master_flavor_id',
+            'flavor_id': 'flavor_id',
         }
         self.context.user_name = 'fake_user'
-        self.context.tenant = 'fake_tenant'
+        self.context.project_id = 'fake_tenant'
         osc_patcher = mock.patch('magnum.common.clients.OpenStackClients')
         self.mock_osc_class = osc_patcher.start()
         self.addCleanup(osc_patcher.stop)
@@ -159,8 +185,19 @@ class TestClusterConductorWithK8s(base.TestCase):
                        'prometheus_monitoring': 'False',
                        'grafana_admin_passwd': 'fake_pwd',
                        'kube_dashboard_enabled': 'True',
+                       'influx_grafana_dashboard_enabled': 'True',
                        'docker_volume_type': 'lvmdriver-1',
-                       'etcd_volume_size': '0'},
+                       'etcd_volume_size': None,
+                       'availability_zone': 'az_1',
+                       'cert_manager_api': 'False',
+                       'ingress_controller': 'i-controller',
+                       'ingress_controller_role': 'i-controller-role',
+                       'kubelet_options': '--kubelet',
+                       'kubeapi_options': '--kubeapi',
+                       'kubecontroller_options': '--kubecontroller',
+                       'kubescheduler_options': '--kubescheduler',
+                       'kubeproxy_options': '--kubeproxy',
+                       },
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -186,7 +223,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'docker_volume_type': 'lvmdriver-1',
             'docker_storage_driver': 'devicemapper',
             'discovery_url': 'https://discovery.etcd.io/test',
-            'etcd_volume_size': '0',
+            'etcd_volume_size': None,
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
             'flannel_backend': 'vxlan',
@@ -196,6 +233,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'prometheus_monitoring': 'False',
             'grafana_admin_passwd': 'fake_pwd',
             'kube_dashboard_enabled': 'True',
+            'influx_grafana_dashboard_enabled': 'True',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -213,6 +251,18 @@ class TestClusterConductorWithK8s(base.TestCase):
             'auth_url': 'http://192.168.10.10:5000/v3',
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
+            'verify_ca': True,
+            'openstack_ca': '',
+            "nodes_affinity_policy": "soft-anti-affinity",
+            'availability_zone': 'az_1',
+            'cert_manager_api': 'False',
+            'ingress_controller': 'i-controller',
+            'ingress_controller_role': 'i-controller-role',
+            'kubelet_options': '--kubelet',
+            'kubeapi_options': '--kubeapi',
+            'kubecontroller_options': '--kubecontroller',
+            'kubescheduler_options': '--kubescheduler',
+            'kubeproxy_options': '--kubeproxy',
         }
         if missing_attr is not None:
             expected.pop(mapping[missing_attr], None)
@@ -269,7 +319,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'docker_storage_driver': 'devicemapper',
             'docker_volume_size': 20,
             'docker_volume_type': 'lvmdriver-1',
-            'etcd_volume_size': '0',
+            'etcd_volume_size': None,
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
@@ -282,6 +332,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'prometheus_monitoring': 'False',
             'grafana_admin_passwd': 'fake_pwd',
             'kube_dashboard_enabled': 'True',
+            'influx_grafana_dashboard_enabled': 'True',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'magnum_url': 'http://127.0.0.1:9511/v1',
@@ -307,6 +358,18 @@ class TestClusterConductorWithK8s(base.TestCase):
             'volume_driver': 'volume_driver',
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
+            'verify_ca': True,
+            'openstack_ca': '',
+            "nodes_affinity_policy": "soft-anti-affinity",
+            'availability_zone': 'az_1',
+            'cert_manager_api': 'False',
+            'ingress_controller': 'i-controller',
+            'ingress_controller_role': 'i-controller-role',
+            'kubelet_options': '--kubelet',
+            'kubeapi_options': '--kubeapi',
+            'kubecontroller_options': '--kubecontroller',
+            'kubescheduler_options': '--kubescheduler',
+            'kubeproxy_options': '--kubeproxy',
         }
 
         self.assertEqual(expected, definition)
@@ -359,6 +422,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             'cluster_uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a52',
             'discovery_url': 'https://discovery.etcd.io/test',
             'docker_volume_size': 20,
+            'master_flavor': 'master_flavor_id',
+            'minion_flavor': 'flavor_id',
             'external_network': 'external_network_id',
             'flannel_backend': 'vxlan',
             'flannel_network_cidr': '10.101.0.0/16',
@@ -369,8 +434,9 @@ class TestClusterConductorWithK8s(base.TestCase):
             'prometheus_monitoring': 'False',
             'grafana_admin_passwd': 'fake_pwd',
             'kube_dashboard_enabled': 'True',
+            'influx_grafana_dashboard_enabled': 'True',
             'docker_volume_type': 'lvmdriver-1',
-            'etcd_volume_size': '0',
+            'etcd_volume_size': None,
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
             'magnum_url': 'http://127.0.0.1:9511/v1',
@@ -385,7 +451,19 @@ class TestClusterConductorWithK8s(base.TestCase):
             'trustee_password': 'fake_trustee_password',
             'trustee_user_id': '7b489f04-b458-4541-8179-6a48a553e656',
             'trustee_username': 'fake_trustee',
-            'username': 'fake_user'
+            'username': 'fake_user',
+            'verify_ca': True,
+            'openstack_ca': '',
+            "nodes_affinity_policy": "soft-anti-affinity",
+            'availability_zone': 'az_1',
+            'cert_manager_api': 'False',
+            'ingress_controller': 'i-controller',
+            'ingress_controller_role': 'i-controller-role',
+            'kubelet_options': '--kubelet',
+            'kubeapi_options': '--kubeapi',
+            'kubecontroller_options': '--kubecontroller',
+            'kubescheduler_options': '--kubescheduler',
+            'kubeproxy_options': '--kubeproxy',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -437,7 +515,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'network_driver': 'network_driver',
             'volume_driver': 'volume_driver',
             'discovery_url': 'https://discovery.etcd.io/test',
-            'etcd_volume_size': '0',
+            'etcd_volume_size': None,
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -450,6 +528,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'prometheus_monitoring': 'False',
             'grafana_admin_passwd': 'fake_pwd',
             'kube_dashboard_enabled': 'True',
+            'influx_grafana_dashboard_enabled': 'True',
             'tls_disabled': False,
             'registry_enabled': False,
             'trustee_domain_id': self.mock_keystone.trustee_domain_id,
@@ -462,6 +541,16 @@ class TestClusterConductorWithK8s(base.TestCase):
             'magnum_url': self.mock_osc.magnum_url.return_value,
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
+            'verify_ca': True,
+            'openstack_ca': '',
+            'cert_manager_api': 'False',
+            'ingress_controller': 'i-controller',
+            'ingress_controller_role': 'i-controller-role',
+            'kubelet_options': '--kubelet',
+            'kubeapi_options': '--kubeapi',
+            'kubecontroller_options': '--kubecontroller',
+            'kubescheduler_options': '--kubescheduler',
+            'kubeproxy_options': '--kubeproxy',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -508,7 +597,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'network_driver': 'network_driver',
             'volume_driver': 'volume_driver',
             'discovery_url': 'http://tokentest/h1/h2/h3',
-            'etcd_volume_size': '0',
+            'etcd_volume_size': None,
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -521,6 +610,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'prometheus_monitoring': 'False',
             'grafana_admin_passwd': 'fake_pwd',
             'kube_dashboard_enabled': 'True',
+            'influx_grafana_dashboard_enabled': 'True',
             'tls_disabled': False,
             'registry_enabled': False,
             'trustee_domain_id': self.mock_keystone.trustee_domain_id,
@@ -533,6 +623,16 @@ class TestClusterConductorWithK8s(base.TestCase):
             'magnum_url': self.mock_osc.magnum_url.return_value,
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
+            'verify_ca': True,
+            'openstack_ca': '',
+            'cert_manager_api': 'False',
+            'ingress_controller': 'i-controller',
+            'ingress_controller_role': 'i-controller-role',
+            'kubelet_options': '--kubelet',
+            'kubeapi_options': '--kubeapi',
+            'kubecontroller_options': '--kubecontroller',
+            'kubescheduler_options': '--kubescheduler',
+            'kubeproxy_options': '--kubeproxy',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -571,21 +671,6 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_get,
             missing_attr='image_id')
 
-    @patch('requests.get')
-    @patch('magnum.objects.ClusterTemplate.get_by_uuid')
-    @patch('magnum.drivers.common.driver.Driver.get_driver')
-    def test_extract_template_definition_without_minion_flavor(
-            self,
-            mock_driver,
-            mock_objects_cluster_template_get_by_uuid,
-            mock_get):
-        mock_driver.return_value = k8s_dr.Driver()
-        self._test_extract_template_definition(
-            mock_driver,
-            mock_objects_cluster_template_get_by_uuid,
-            mock_get,
-            missing_attr='flavor_id')
-
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
@@ -601,21 +686,6 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_get,
             missing_attr='docker_storage_driver')
 
-    @patch('requests.get')
-    @patch('magnum.objects.ClusterTemplate.get_by_uuid')
-    @patch('magnum.drivers.common.driver.Driver.get_driver')
-    def test_extract_template_definition_without_master_flavor(
-            self,
-            mock_driver,
-            mock_objects_cluster_template_get_by_uuid,
-            mock_get):
-        mock_driver.return_value = k8s_dr.Driver()
-        self._test_extract_template_definition(
-            mock_driver,
-            mock_objects_cluster_template_get_by_uuid,
-            mock_get,
-            missing_attr='master_flavor_id')
-
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
@@ -706,7 +776,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'docker_volume_type': 'lvmdriver-1',
             'docker_storage_driver': 'devicemapper',
             'discovery_url': 'https://address/token',
-            'etcd_volume_size': '0',
+            'etcd_volume_size': None,
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -719,6 +789,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'prometheus_monitoring': 'False',
             'grafana_admin_passwd': 'fake_pwd',
             'kube_dashboard_enabled': 'True',
+            'influx_grafana_dashboard_enabled': 'True',
             'username': 'fake_user',
             'cluster_uuid': self.cluster_dict['uuid'],
             'magnum_url': self.mock_osc.magnum_url.return_value,
@@ -733,6 +804,18 @@ class TestClusterConductorWithK8s(base.TestCase):
             'auth_url': 'http://192.168.10.10:5000/v3',
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
+            'verify_ca': True,
+            'openstack_ca': '',
+            "nodes_affinity_policy": "soft-anti-affinity",
+            'availability_zone': 'az_1',
+            'cert_manager_api': 'False',
+            'ingress_controller': 'i-controller',
+            'ingress_controller_role': 'i-controller-role',
+            'kubelet_options': '--kubelet',
+            'kubeapi_options': '--kubeapi',
+            'kubecontroller_options': '--kubecontroller',
+            'kubescheduler_options': '--kubescheduler',
+            'kubeproxy_options': '--kubeproxy',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -757,7 +840,7 @@ class TestClusterConductorWithK8s(base.TestCase):
                           mock_generate_id):
 
         mock_generate_id.return_value = 'xx-xx-xx-xx'
-        expected_stack_name = 'expected_stack_name-xx-xx-xx-xx'
+        expected_stack_name = 'expected-stack-name-xx-xx-xx-xx'
         expected_template_contents = 'template_contents'
         dummy_cluster_name = 'expected_stack_name'
         expected_timeout = 15
@@ -798,7 +881,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_generate_id):
 
         mock_generate_id.return_value = 'xx-xx-xx-xx'
-        expected_stack_name = 'expected_stack_name-xx-xx-xx-xx'
+        expected_stack_name = 'expected-stack-name-xx-xx-xx-xx'
         expected_template_contents = 'template_contents'
         dummy_cluster_name = 'expected_stack_name'
         expected_timeout = CONF.cluster_heat.create_timeout
@@ -838,7 +921,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_generate_id):
 
         mock_generate_id.return_value = 'xx-xx-xx-xx'
-        expected_stack_name = 'expected_stack_name-xx-xx-xx-xx'
+        expected_stack_name = 'expected-stack-name-xx-xx-xx-xx'
         expected_template_contents = 'template_contents'
         dummy_cluster_name = 'expected_stack_name'
         cluster_timeout = 0
