@@ -233,6 +233,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
         mock_cluster_template = mock.MagicMock()
         mock_cluster_template.tls_disabled = False
         mock_cluster_template.registry_enabled = False
+        mock_cluster_template.network_driver = 'flannel'
         mock_cluster = mock.MagicMock()
         mock_cluster.uuid = '5d12f6fd-a196-4bf0-ae4c-1f639a523a52'
         del mock_cluster.stack_id
@@ -249,27 +250,62 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
         mock_context.auth_url = 'http://192.168.10.10:5000/v3'
         mock_context.user_name = 'fake_user'
 
-        flannel_cidr = mock_cluster_template.labels.get('flannel_network_cidr')
-        flannel_subnet = mock_cluster_template.labels.get(
+        flannel_cidr = mock_cluster.labels.get('flannel_network_cidr')
+        flannel_subnet = mock_cluster.labels.get(
             'flannel_network_subnetlen')
-        flannel_backend = mock_cluster_template.labels.get('flannel_backend')
-        system_pods_initial_delay = mock_cluster_template.labels.get(
+        flannel_backend = mock_cluster.labels.get('flannel_backend')
+        system_pods_initial_delay = mock_cluster.labels.get(
             'system_pods_initial_delay')
-        system_pods_timeout = mock_cluster_template.labels.get(
+        system_pods_timeout = mock_cluster.labels.get(
             'system_pods_timeout')
-        admission_control_list = mock_cluster_template.labels.get(
+        admission_control_list = mock_cluster.labels.get(
             'admission_control_list')
-        prometheus_monitoring = mock_cluster_template.labels.get(
+        prometheus_monitoring = mock_cluster.labels.get(
             'prometheus_monitoring')
-        grafana_admin_passwd = mock_cluster_template.labels.get(
+        grafana_admin_passwd = mock_cluster.labels.get(
             'grafana_admin_passwd')
-        kube_dashboard_enabled = mock_cluster_template.labels.get(
+        kube_dashboard_enabled = mock_cluster.labels.get(
             'kube_dashboard_enabled')
-        docker_volume_type = mock_cluster_template.labels.get(
+        influx_grafana_dashboard_enabled = mock_cluster.labels.get(
+            'influx_grafana_dashboard_enabled')
+        docker_volume_type = mock_cluster.labels.get(
             'docker_volume_type')
-        etcd_volume_size = mock_cluster_template.labels.get(
+        etcd_volume_size = mock_cluster.labels.get(
             'etcd_volume_size')
-        kube_tag = mock_cluster_template.labels.get('kube_tag')
+        kube_tag = mock_cluster.labels.get('kube_tag')
+        etcd_tag = mock_cluster.labels.get('etcd_tag')
+        flannel_tag = mock_cluster.labels.get('flannel_tag')
+        container_infra_prefix = mock_cluster.labels.get(
+            'container_infra_prefix')
+        availability_zone = mock_cluster.labels.get(
+            'availability_zone')
+        cert_manager_api = mock_cluster.labels.get('cert_manager_api')
+        calico_tag = mock_cluster.labels.get(
+            'calico_tag')
+        calico_cni_tag = mock_cluster.labels.get(
+            'calico_cni_tag')
+        calico_kube_controllers_tag = mock_cluster.labels.get(
+            'calico_kube_controllers_tag')
+        calico_ipv4pool = mock_cluster.labels.get(
+            'calico_ipv4pool')
+        if mock_cluster_template.network_driver == 'flannel':
+            pods_network_cidr = flannel_cidr
+        elif mock_cluster_template.network_driver == 'calico':
+            pods_network_cidr = calico_ipv4pool
+        ingress_controller = mock_cluster.labels.get(
+            'ingress_controller')
+        ingress_controller_role = mock_cluster.labels.get(
+            'ingress_controller_role')
+        kubelet_options = mock_cluster.labels.get(
+            'kubelet_options')
+        kubeapi_options = mock_cluster.labels.get(
+            'kubeapi_options')
+        kubecontroller_options = mock_cluster.labels.get(
+            'kubecontroller_options')
+        kubescheduler_options = mock_cluster.labels.get(
+            'kubescheduler_options')
+        kubeproxy_options = mock_cluster.labels.get(
+            'kubeproxy_options')
 
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
@@ -288,12 +324,32 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'prometheus_monitoring': prometheus_monitoring,
             'grafana_admin_passwd': grafana_admin_passwd,
             'kube_dashboard_enabled': kube_dashboard_enabled,
+            'influx_grafana_dashboard_enabled':
+                influx_grafana_dashboard_enabled,
             'docker_volume_type': docker_volume_type,
             'etcd_volume_size': etcd_volume_size,
+            'kubelet_options': kubelet_options,
+            'kubeapi_options': kubeapi_options,
+            'kubecontroller_options': kubecontroller_options,
+            'kubescheduler_options': kubescheduler_options,
+            'kubeproxy_options': kubeproxy_options,
             'username': 'fake_user',
             'magnum_url': mock_osc.magnum_url.return_value,
             'region_name': mock_osc.cinder_region_name.return_value,
-            'kube_tag': kube_tag}}
+            'kube_tag': kube_tag,
+            'etcd_tag': etcd_tag,
+            'flannel_tag': flannel_tag,
+            'container_infra_prefix': container_infra_prefix,
+            'nodes_affinity_policy': 'soft-anti-affinity',
+            'availability_zone': availability_zone,
+            'cert_manager_api': cert_manager_api,
+            'calico_tag': calico_tag,
+            'calico_cni_tag': calico_cni_tag,
+            'calico_kube_controllers_tag': calico_kube_controllers_tag,
+            'calico_ipv4pool': calico_ipv4pool,
+            'pods_network_cidr': pods_network_cidr,
+            'ingress_controller': ingress_controller,
+            'ingress_controller_role': ingress_controller_role}}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
                                                 mock_cluster,
@@ -313,6 +369,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
         mock_cluster_template = mock.MagicMock()
         mock_cluster_template.tls_disabled = True
         mock_cluster_template.registry_enabled = False
+        mock_cluster_template.network_driver = 'calico'
         mock_cluster = mock.MagicMock()
         mock_cluster.uuid = '5d12f6fd-a196-4bf0-ae4c-1f639a523a52'
         del mock_cluster.stack_id
@@ -329,27 +386,62 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
         mock_context.auth_url = 'http://192.168.10.10:5000/v3'
         mock_context.user_name = 'fake_user'
 
-        flannel_cidr = mock_cluster_template.labels.get('flannel_network_cidr')
-        flannel_subnet = mock_cluster_template.labels.get(
+        flannel_cidr = mock_cluster.labels.get('flannel_network_cidr')
+        flannel_subnet = mock_cluster.labels.get(
             'flannel_network_subnetlen')
-        flannel_backend = mock_cluster_template.labels.get('flannel_backend')
-        system_pods_initial_delay = mock_cluster_template.labels.get(
+        flannel_backend = mock_cluster.labels.get('flannel_backend')
+        system_pods_initial_delay = mock_cluster.labels.get(
             'system_pods_initial_delay')
-        system_pods_timeout = mock_cluster_template.labels.get(
+        system_pods_timeout = mock_cluster.labels.get(
             'system_pods_timeout')
-        admission_control_list = mock_cluster_template.labels.get(
+        admission_control_list = mock_cluster.labels.get(
             'admission_control_list')
-        prometheus_monitoring = mock_cluster_template.labels.get(
+        prometheus_monitoring = mock_cluster.labels.get(
             'prometheus_monitoring')
-        grafana_admin_passwd = mock_cluster_template.labels.get(
+        grafana_admin_passwd = mock_cluster.labels.get(
             'grafana_admin_passwd')
-        kube_dashboard_enabled = mock_cluster_template.labels.get(
+        kube_dashboard_enabled = mock_cluster.labels.get(
             'kube_dashboard_enabled')
-        docker_volume_type = mock_cluster_template.labels.get(
+        influx_grafana_dashboard_enabled = mock_cluster.labels.get(
+            'influx_grafana_dashboard_enabled')
+        docker_volume_type = mock_cluster.labels.get(
             'docker_volume_type')
-        etcd_volume_size = mock_cluster_template.labels.get(
+        etcd_volume_size = mock_cluster.labels.get(
             'etcd_volume_size')
-        kube_tag = mock_cluster_template.labels.get('kube_tag')
+        kube_tag = mock_cluster.labels.get('kube_tag')
+        etcd_tag = mock_cluster.labels.get('etcd_tag')
+        flannel_tag = mock_cluster.labels.get('flannel_tag')
+        container_infra_prefix = mock_cluster.labels.get(
+            'container_infra_prefix')
+        availability_zone = mock_cluster.labels.get(
+            'availability_zone')
+        cert_manager_api = mock_cluster.labels.get('cert_manager_api')
+        calico_tag = mock_cluster.labels.get(
+            'calico_tag')
+        calico_cni_tag = mock_cluster.labels.get(
+            'calico_cni_tag')
+        calico_kube_controllers_tag = mock_cluster.labels.get(
+            'calico_kube_controllers_tag')
+        calico_ipv4pool = mock_cluster.labels.get(
+            'calico_ipv4pool')
+        if mock_cluster_template.network_driver == 'flannel':
+            pods_network_cidr = flannel_cidr
+        elif mock_cluster_template.network_driver == 'calico':
+            pods_network_cidr = calico_ipv4pool
+        ingress_controller = mock_cluster.labels.get(
+            'ingress_controller')
+        ingress_controller_role = mock_cluster.labels.get(
+            'ingress_controller_role')
+        kubelet_options = mock_cluster.labels.get(
+            'kubelet_options')
+        kubeapi_options = mock_cluster.labels.get(
+            'kubeapi_options')
+        kubecontroller_options = mock_cluster.labels.get(
+            'kubecontroller_options')
+        kubescheduler_options = mock_cluster.labels.get(
+            'kubescheduler_options')
+        kubeproxy_options = mock_cluster.labels.get(
+            'kubeproxy_options')
 
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
@@ -368,14 +460,34 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'prometheus_monitoring': prometheus_monitoring,
             'grafana_admin_passwd': grafana_admin_passwd,
             'kube_dashboard_enabled': kube_dashboard_enabled,
+            'influx_grafana_dashboard_enabled':
+                influx_grafana_dashboard_enabled,
             'docker_volume_type': docker_volume_type,
             'etcd_volume_size': etcd_volume_size,
+            'kubelet_options': kubelet_options,
+            'kubeapi_options': kubeapi_options,
+            'kubecontroller_options': kubecontroller_options,
+            'kubescheduler_options': kubescheduler_options,
+            'kubeproxy_options': kubeproxy_options,
             'username': 'fake_user',
             'magnum_url': mock_osc.magnum_url.return_value,
             'region_name': mock_osc.cinder_region_name.return_value,
             'loadbalancing_protocol': 'HTTP',
             'kubernetes_port': 8080,
-            'kube_tag': kube_tag}}
+            'kube_tag': kube_tag,
+            'etcd_tag': etcd_tag,
+            'flannel_tag': flannel_tag,
+            'container_infra_prefix': container_infra_prefix,
+            'nodes_affinity_policy': 'soft-anti-affinity',
+            'availability_zone': availability_zone,
+            'cert_manager_api': cert_manager_api,
+            'calico_tag': calico_tag,
+            'calico_cni_tag': calico_cni_tag,
+            'calico_kube_controllers_tag': calico_kube_controllers_tag,
+            'calico_ipv4pool': calico_ipv4pool,
+            'pods_network_cidr': pods_network_cidr,
+            'ingress_controller': ingress_controller,
+            'ingress_controller_role': ingress_controller_role}}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
                                                 mock_cluster,
@@ -761,14 +873,14 @@ class AtomicSwarmTemplateDefinitionTestCase(base.TestCase):
         mock_context.user_name = 'fake_user'
         mock_context.tenant = 'fake_tenant'
 
-        docker_volume_type = mock_cluster_template.labels.get(
+        docker_volume_type = mock_cluster.labels.get(
             'docker_volume_type')
-        flannel_cidr = mock_cluster_template.labels.get('flannel_network_cidr')
-        flannel_subnet = mock_cluster_template.labels.get(
+        flannel_cidr = mock_cluster.labels.get('flannel_network_cidr')
+        flannel_subnet = mock_cluster.labels.get(
             'flannel_network_subnetlen')
-        flannel_backend = mock_cluster_template.labels.get('flannel_backend')
-        rexray_preempt = mock_cluster_template.labels.get('rexray_preempt')
-        swarm_strategy = mock_cluster_template.labels.get('swarm_strategy')
+        flannel_backend = mock_cluster.labels.get('flannel_backend')
+        rexray_preempt = mock_cluster.labels.get('rexray_preempt')
+        swarm_strategy = mock_cluster.labels.get('swarm_strategy')
 
         swarm_def = swarm_tdef.AtomicSwarmTemplateDefinition()
 
@@ -783,7 +895,8 @@ class AtomicSwarmTemplateDefinitionTestCase(base.TestCase):
             'auth_url': 'http://192.168.10.10:5000/v3',
             'rexray_preempt': rexray_preempt,
             'swarm_strategy': swarm_strategy,
-            'docker_volume_type': docker_volume_type}}
+            'docker_volume_type': docker_volume_type,
+            'nodes_affinity_policy': 'soft-anti-affinity'}}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
                                                 mock_cluster,
@@ -919,22 +1032,22 @@ class UbuntuMesosTemplateDefinitionTestCase(base.TestCase):
         mock_context = mock.MagicMock()
         mock_context.auth_url = 'http://192.168.10.10:5000/v3'
         mock_context.user_name = 'mesos_user'
-        mock_context.tenant = 'admin'
+        mock_context.project_id = 'admin'
         mock_context.domain_name = 'domainname'
         mock_cluster_template = mock.MagicMock()
         mock_cluster_template.tls_disabled = False
-        rexray_preempt = mock_cluster_template.labels.get('rexray_preempt')
-        mesos_slave_isolation = mock_cluster_template.labels.get(
-            'mesos_slave_isolation')
-        mesos_slave_work_dir = mock_cluster_template.labels.get(
-            'mesos_slave_work_dir')
-        mesos_slave_image_providers = mock_cluster_template.labels.get(
-            'image_providers')
-        mesos_slave_executor_env_variables = mock_cluster_template.labels.get(
-            'mesos_slave_executor_env_variables')
         mock_cluster = mock.MagicMock()
         mock_cluster.uuid = '5d12f6fd-a196-4bf0-ae4c-1f639a523a52'
         del mock_cluster.stack_id
+        rexray_preempt = mock_cluster.labels.get('rexray_preempt')
+        mesos_slave_isolation = mock_cluster.labels.get(
+            'mesos_slave_isolation')
+        mesos_slave_work_dir = mock_cluster.labels.get(
+            'mesos_slave_work_dir')
+        mesos_slave_image_providers = mock_cluster.labels.get(
+            'image_providers')
+        mesos_slave_executor_env_variables = mock_cluster.labels.get(
+            'mesos_slave_executor_env_variables')
         mock_osc = mock.MagicMock()
         mock_osc.cinder_region_name.return_value = 'RegionOne'
         mock_osc_class.return_value = mock_osc
